#
# spec file for package pidentd
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pidentd
Version:        3.0.19
Release:        lp150.2.4
Summary:        An Implementation of the RFC1413 Identification Server
License:        SUSE-Public-Domain
Group:          Productivity/Networking/System
Url:            https://github.com/ptrrkssn/pidentd
Source:         https://github.com/ptrrkssn/pidentd/archive/v%{version}.tar.gz
Source1:        pidentd.service
Patch0:         pidentd-destdir.patch
Patch1:         01-legacy.patch
Patch2:         pidentd-rpmlint-gcc-checks.patch
Patch3:         pidentd-no-date.patch
BuildRequires:  autoconf
BuildRequires:  libtool

%description
This package contains identd, which implements a RFC1413 identification
server.  Identd looks up specific TCP/IP connections and returns the
user name and other information about the connection.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
autoconf
%configure
make %{?_smp_mflags}

%install
%make_install
install -D -m 0644 etc/identd.conf %{buildroot}%{_sysconfdir}/identd.conf
ln -s identd %{buildroot}%{_sbindir}/in.identd
echo ".so man8/identd.8" > %{buildroot}%{_mandir}/man8/in.identd.8

ln -s service %{buildroot}%{_sbindir}/rcidentd
install -D -m 0644 %{SOURCE1} %{buildroot}/%{_unitdir}/identd.service

mkdir -p %{buildroot}%{_tmpfilesdir}
cat > %{buildroot}%{_tmpfilesdir}/pidentd.conf <<EOF
# See tmpfiles.d(5) for details
d %{_localstatedir}/run/identd 0755 root root - -
EOF

%pre
%service_add_pre identd.service

%post
%tmpfiles_create %{_tmpfilesdir}/pidentd.conf
%service_add_post identd.service

%preun
%service_del_preun identd.service

%postun
%service_del_postun identd.service

%files
%defattr(-,root,root)
%config %{_sysconfdir}/identd.conf
%doc ChangeLog* FAQ README
%{_tmpfilesdir}/pidentd.conf
%{_unitdir}/identd.service
%{_mandir}/man?/*
%{_sbindir}/*

%changelog
* Fri Apr  6 2018 coolo@suse.com
- latest sources dropped plib/strmatch.c and as such all the sources
  are PD now. License is basically 'you can do whatever you want
  as long as you don't claim you wrote it'
* Fri Apr  6 2018 kukuk@suse.de
- Remove obsolete requires for inetd
* Fri Jun 16 2017 tchvatal@suse.com
- Switch to github url
- Remove pidentd-SuSE.tar.bz2 as it contains only sysv initscript
- Remove xinetd service as we should be using socket activation if needed
  (atm it really is not required so do not provide it by default)
- Switch to released upstream tarball 3.0.19 used by all other distributions
- Drop all the patches, upstream seem to merge or include them one
  way or another:
  * pidentd-3.1a25-allocfix.diff
  * pidentd-3.1a25-autoconf.diff
  * pidentd-3.1a25-autoheader.diff
  * pidentd-3.1a25-buffer-overflow.diff
  * pidentd-3.1a25-config.diff
  * pidentd-3.1a25-fmt.diff
  * pidentd-3.1a25-ipv6.diff
  * pidentd-3.1a25-prototypes.diff
  * pidentd-3.1a25-send.diff
  * pidentd-3.1a25-warnings-fix.diff
- Add patch to respect destdir in install:
  * pidentd-destdir.patch
- Add patch from debian:
  * 01-legacy.patch
- Add patch to fix gcc errors found by brp checks:
  * pidentd-rpmlint-gcc-checks.patch
- Add patch to not include date/time in binaries:
  * pidentd-no-date.patch
- Install proper systemd service
* Tue May 22 2012 frank.lichtenheld@sophos.com
- Make build with current tools
  * Fix autoheader errors by adding descriptions to AC_DEFINE
  calls
  * Copy config.* manually since suse_update_config is not doing
  it anymore and autoreconf does not take care of it because
  pidentd doesn't use automake.
* Tue Mar 27 2012 cfarrell@suse.com
- license update: GPL-2.0+
  SeSee plib/strmatch.c
* Sun Nov 27 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Wed Apr  7 2010 crrodriguez@opensuse.org
- require inet-daemon
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Fri Aug 22 2008 ro@suse.de
- remove deprecated startvar from fillup_and_insserv call
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 12 2005 mjancar@suse.cz
- more fixes to the ipv6 support
- split patches by subject
* Fri Sep 16 2005 mjancar@suse.cz
- fix ipv6 support (#53558)
* Wed Apr 28 2004 postadal@suse.cz
- fixed rewind(3) issue and examining local connections in both directions
  [#38558]
* Tue Apr 27 2004 postadal@suse.cz
- redirected std* streams to /dev/null in init script [#38860]
* Fri Feb 27 2004 postadal@suse.cz
- fixed mazy syslog messaged with "buffer overflow" and compilation warnings
  [#33438]
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Oct 17 2003 kukuk@suse.de
- Build without DES support (broken on all 64bit archs)
* Fri Sep 19 2003 mjancar@suse.cz
- fix xinetd configuration file
  * start as root - pidentd switches to nobody itself and complains when can't
  * non waiting mode requires -i switch
* Fri Aug 29 2003 kukuk@suse.de
- Don't activate in.identd per default
* Mon Aug 25 2003 postadal@suse.cz
- use new stop_on_removal/restart_on_upate macros
* Thu Mar  6 2003 postadal@suse.cz
- created config file for xinetd [#24693]
* Mon Feb 24 2003 postadal@suse.cz
- cleared specfile
* Tue Feb 11 2003 postadal@suse.cz
- fixed bad allocating of memory [#23480]
* Fri Jan 31 2003 postadal@suse.cz
- updated to version 3.1a25
  * various PLIB updates and synchronisation with pftpd
* Fri Aug 16 2002 postadal@suse.cz
- added %%insserv_prereq and %%fillup_prereq to PreReq [#17941]
* Wed Jul 31 2002 postadal@suse.cz
- update to version 3.1a24 - fixes
- removed sourcing rc.config (bug #17310)
* Mon Dec 10 2001 cihlar@suse.cz
- removed START_IDENTD
* Thu Jul 26 2001 cihlar@suse.cz
- update to version 3.1a19
* Wed Jun  6 2001 cihlar@suse.cz
- fixed to compile with new autoconf
* Thu May 10 2001 cihlar@suse.cz
- fixed to not start on runlevel 2 [#7954]
* Fri Apr 13 2001 cihlar@suse.cz
- fixed init script by new skeleton
* Thu Mar 22 2001 ro@suse.de
- added split-aliases as provides
* Tue Feb 27 2001 cihlar@suse.cz
- fixed %%files
- fixed start script to agree with skeleton
* Mon Jan 22 2001 smid@suse.cz
- fix to work with kernels that don't have IPv6 support [#6043]
* Tue Jan  9 2001 smid@suse.cz
- config file chnged [#5189]
* Tue Dec  5 2000 smid@suse.cz
- new version 3.1a17
- fixed bug with query len >1024
* Fri Dec  1 2000 ro@suse.de
- fixed startscript
* Wed Apr 12 2000 kukuk@suse.de
- New package, split from nkitb
